/*
** Module   : Os.java
** Abstract : operating systems enumeration.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------Description--------------------------
** 001 MAG 20131128 First version.
*/

package com.goldencode.p2j.main;

/**
 * Operating systems enumeration.
 * 
 * @author mag
 *
 */
public enum Os
{
   /** Unix or Linux OS */
   OS_LINUX,
   
   /** Windows OS */
   OS_WINDOWS,
   
   /** MAC OS */
   OS_MAC,
   
   /** SOLARIS OS */
   OS_SOLARIS,

   /** OS/2 */
   OS_OS2,
   
   /** Unknown OS */   
   OS_UNKNOWN;

   /** Operating system */
   private static volatile Os os;
        
   /**
    * Return the platform on which the server is running.
    * 
    * @return  Operating system enum.
    */
   public static Os getOs()
   {
      if (os == null) 
      {
         synchronized (Os.class)
         {
            String osName = System.getProperty("os.name").toLowerCase();     
            
            if (osName.indexOf("nix") >= 0 || 
                osName.indexOf("nux") >= 0 || 
                osName.indexOf("aix") >= 0)
            {
               os = OS_LINUX;
            }
            else if (osName.indexOf("win") >= 0)
            {
               os = OS_WINDOWS;
            }
            else if (osName.indexOf("mac") >= 0)
            {
               os =  OS_MAC;
            }
            else if (osName.indexOf("sunos") >= 0)
            {
               os = OS_SOLARIS;
            }
            else if (osName.indexOf("os/2") >= 0)
            {
               os = OS_OS2;
            }
            else
            {            
               os = OS_UNKNOWN;
            }
         }
      }
      
      return os;
   }
}
